@@ -59,7 +59,7 @@ class Boundaries(list):
     def from_data(cls, grid: GridBase, boundaries, rank: int = 0) -> "Boundaries":
         """
         Creates all boundaries from given data
-        
+
         Args:
             grid (:class:`~pde.grids.base.GridBase`):
                 The grid with which the boundary condition is associated
@@ -68,14 +68,14 @@ class Boundaries(list):
                 specifications for each dimension or a single one, which is then
                 applied to all dimensions. The boundary for a dimensions can be
                 specified by one of the following formats:
-                
+
                 * string specifying a single type for all boundaries
                 * dictionary specifying the type and values for all boundaries
                 * tuple pair specifying the low and high boundary individually
             rank (int):
                 The tensorial rank of the value associated with the boundary
                 conditions.
-                
+
         """
         # check whether this is already the correct class
         if isinstance(boundaries, Boundaries):
@@ -97,24 +97,30 @@ class Boundaries(list):
             ]
 
         # create the list of BoundaryAxis objects
+        bcs = None
         if isinstance(boundaries, (str, dict)):
             # one specification for all axes
             bcs = [
                 get_boundary_axis(grid, i, boundaries, rank=rank)
                 for i in range(grid.num_axes)
             ]
-        elif len(boundaries) == grid.num_axes:
-            # assume that data is given for each boundary
-            bcs = [
-                get_boundary_axis(grid, i, boundary, rank=rank)
-                for i, boundary in enumerate(boundaries)
-            ]
-        elif grid.num_axes == 1 and len(boundaries) == 2:
-            # special case where the two sides can be specified directly
-            bcs = [get_boundary_axis(grid, 0, boundaries, rank=rank)]
-        else:
+
+        elif hasattr(boundaries, "__len__"):
+            # handle cases that look like sequences
+            if len(boundaries) == grid.num_axes:
+                # assume that data is given for each boundary
+                bcs = [
+                    get_boundary_axis(grid, i, boundary, rank=rank)
+                    for i, boundary in enumerate(boundaries)
+                ]
+            elif grid.num_axes == 1 and len(boundaries) == 2:
+                # special case where the two sides can be specified directly
+                bcs = [get_boundary_axis(grid, 0, boundaries, rank=rank)]
+
+        if bcs is None:
+            # none of the logic worked
             raise ValueError(
-                f"Unsupported boundary format: `{boundaries}`." + cls.get_help()
+                f"Unsupported boundary format: `{boundaries}`. " + cls.get_help()
             )
 
         return cls(bcs)
@@ -129,12 +135,12 @@ class Boundaries(list):
         return hash(tuple(bc_ax._cache_hash() for bc_ax in self))
 
     def check_value_rank(self, rank: int):
-        """ check whether the values at the boundaries have the correct rank
-        
+        """check whether the values at the boundaries have the correct rank
+
         Args:
             rank (tuple): The rank of the value that is stored with this
                 boundary condition
-            
+
         Throws:
             RuntimeError: if any value does not have rank `rank`
         """
@@ -151,8 +157,8 @@ class Boundaries(list):
         )
 
     def copy(self, value=None) -> "Boundaries":
-        """ create a copy of the current boundaries
-        
+        """create a copy of the current boundaries
+
         Args:
             value (float or array, optional):
                 If given, this changes the value stored with the boundary
@@ -168,13 +174,13 @@ class Boundaries(list):
 
     @property
     def periodic(self) -> np.ndarray:
-        """ :class:`numpy.ndarray`: a boolean array indicating which dimensions
-        are periodic according to the boundary conditions """
+        """:class:`numpy.ndarray`: a boolean array indicating which dimensions
+        are periodic according to the boundary conditions"""
         return self.grid.periodic
 
     def set_value(self, value=0):
-        """ set the value of all non-periodic boundaries
-        
+        """set the value of all non-periodic boundaries
+
         Args:
             value (float or array):
                 Sets the value stored with the boundary conditions. The
@@ -186,8 +192,8 @@ class Boundaries(list):
                 b.set_value(value)
 
     def scale_value(self, factor: float = 1):
-        """ scales the value of the boundary condition with the given factor
-        
+        """scales the value of the boundary condition with the given factor
+
         Args:
             value (float):
                 Scales the value associated with the boundary condition by the factor
@@ -198,7 +204,7 @@ class Boundaries(list):
 
     @property
     def _scipy_border_mode(self) -> dict:
-        """ dict: return a dictionary that can be used in the scipy ndimage
+        """dict: return a dictionary that can be used in the scipy ndimage
         functions to specify the border mode. If the current boundary cannot be
         represented by these modes, a RuntimeError is raised
         """
@@ -218,7 +224,7 @@ class Boundaries(list):
             raise RuntimeError("Grid discretization is not uniform")
 
     def extract_component(self, *indices) -> "Boundaries":
-        """ extracts the boundary conditions of the given extract_component.
+        """extracts the boundary conditions of the given extract_component.
 
         Args:
             *indices:
