@@ -16,14 +16,14 @@ from .base import PDEBase, expr_prod
 
 
 class KuramotoSivashinskyPDE(PDEBase):
-    r""" The Kuramoto-Sivashinsky equation
-    
+    r"""The Kuramoto-Sivashinsky equation
+
     The mathematical definition is
-    
+
     .. math::
         \partial_t u = -\nu \nabla^4 u  - \nabla^2 u -
             \frac{1}{2} \left(\nabla h\right)^2  + \eta(\boldsymbol r, t)
-        
+
     where :math:`u` is the height of the interface in Monge parameterization.
     The dynamics are governed by the parameters :math:`\nu` , while
     :math:`\eta` is Gaussian white noise, whose strength is controlled by the
@@ -40,7 +40,7 @@ class KuramotoSivashinskyPDE(PDEBase):
         bc: BoundariesData = "natural",
         bc_lap: BoundariesData = None,
     ):
-        r""" 
+        r"""
         Args:
             nu (float):
                 Parameter :math:`\nu` for the strength of the fourth-order term
@@ -68,18 +68,20 @@ class KuramotoSivashinskyPDE(PDEBase):
         return f"-laplace({expr}) - 0.5 * gradient_squared(c)"
 
     def evolution_rate(  # type: ignore
-        self, state: ScalarField, t: float = 0,
+        self,
+        state: ScalarField,
+        t: float = 0,
     ) -> ScalarField:
-        """ evaluate the right hand side of the PDE
-        
+        """evaluate the right hand side of the PDE
+
         Args:
             state (:class:`~pde.fields.ScalarField`):
                 The scalar field describing the concentration distribution
             t (float): The current time point
-            
+
         Returns:
             :class:`~pde.fields.ScalarField`:
-            Scalar field describing the evolution rate of the PDE 
+            Scalar field describing the evolution rate of the PDE
         """
         assert isinstance(state, ScalarField)
         state_lap = state.laplace(bc=self.bc)
@@ -92,17 +94,17 @@ class KuramotoSivashinskyPDE(PDEBase):
         return result  # type: ignore
 
     def _make_pde_rhs_numba(self, state: ScalarField) -> Callable:  # type: ignore
-        """ create a compiled function evaluating the right hand side of the PDE
-        
+        """create a compiled function evaluating the right hand side of the PDE
+
         Args:
             state (:class:`~pde.fields.ScalarField`):
                 An example for the state defining the grid and data types
-                
+
         Returns:
             A function with signature `(state_data, t)`, which can be called
             with an instance of :class:`numpy.ndarray` of the state data and
             the time to obtained an instance of :class:`numpy.ndarray` giving
-            the evolution rate.  
+            the evolution rate.
         """
         shape = state.grid.shape
         arr_type = nb.typeof(np.empty(shape, dtype=np.double))
